#Ecconnect Rails

Rails engine for integration with eCommerceConnect

##Installation

You can let bundler install Ecconnect Rails by adding this line to your application's Gemfile:

```ruby
gem 'ecconnect_rails'
```
And then execute:
```sh
$ bundle install
```
Or install it yourself with:
```sh
$ gem install ecconnect_rails
```

##Basic Usage

### Add initiliazer


config/initiliazers/ecconnect_rails.rb

```ruby
EcconnectRails.default_options = { merchant_id: "merchant_id", 
                                   terminal_id: "terminal_id", 
                                   request_url: "url",
                                   cert_path: Rails.root.join(paht_to_cert)
                                   pem_path: Rails.root.join(paht_to_pem)
                                   currency_id: currency_number }
```

Example
```ruby
EcconnectRails.default_options = { merchant_id: "12345", 
                                   terminal_id: "E1234", 
                                   request_url: "https://secure.upc.ua/ecgtest/enter",
                                   cert_path: Rails.root.join('certs/test-server.cert')
                                   pem_path: Rails.root.join('certs/12345.pem')
                                   currency_id: 980 }
```

### Create model

#### Mongoid

```ruby
require 'autoinc'

class EcconnectPayment
  include EcconnectRails::BaseModel
  include Mongoid::Document
  include Mongoid::Timestamps
  include Mongoid::Autoinc

  field :delay, type: Boolean
  field :merchant_id, type: Integer
  field :terminal_id, type: String
  field :tran_code, type: String
  field :approval_code, type: Integer
  field :locale, type: String
  field :proxy_pan, type: String
  field :currency_id, type: Integer
  field :alt_currency_id, type: Integer
  field :amount, type: Float
  field :alt_amount, type: Integer
  field :order_id, type: Integer
  field :income_signature, type: String
  field :purchase_desc, type: String
  field :email, type: String
  field :sd, type: String
  field :xid, type: String
  field :rrn, type: String

  increments :order_id, seed: 1

  ecconnect_payment
end
```
#### ActiveRecord

### Create controller

```ruby
  class EcconnectPaymentsController < EcconnectRails::BaseController

  private
    def success_right_signature ecconnect_payment
     #Job after recieved success request with right signature
    end
  end
```

You can override other private methods
```ruby
  private
    def success_wrong_signature ecconnect_payment
      #Job after recieved success request with wrong signature
    end

    def failure_right_signature ecconnect_payment
      #Job after recieved failure request with right signature
    end

    def failure_wrong_signature ecconnect_payment
      #Job after recieved failure request with wrong signature
    end

    def notify_right_signature ecconnect_payment
      #Job after recieved notify request with right signature and wrong code
    end

    def notify_right_signature_and_code ecconnect_payment
      #Job after recieved notify request with right signature and code
    end

    def notify_wrong_signature ecconnect_payment
       #Job after recieved notify request with wrong signature
    end
    
    def forward_url_success
       #Return success url for notify
    end

    def forward_url_failure
      #Return failure url for notify
    end
```
### Add routes

```ruby
  resources :ecconnect_payments, only: [:new, :create, :show] do
    collection do
      post 'success'
      post 'failure'
      post 'notify'
    end
  end
```

##TO DO

  - Add generators for ActiveRecord
  - Add specs for ActiveRecord ecconnect model
  - Add generators for Views
  - Add Inherited Resources to BasicController

##License


MIT