require 'spec_helper'

describe EcconnectPaymentsController do
  #routes { EcconnectRails::Engine.routes }
  let(:payment){ FactoryGirl.create :ecconnect_payment }
  describe "GET new" do
    before{ get :new }
    it{ response.status.should == 200 }
    it{ assigns(:ecconnect_payment).should be_a_new(EcconnectPayment) }
  end

  describe "GET show" do
    before{ get :show, id: payment.to_param }
    it{ response.status.should == 200 }
    it{ assigns(:ecconnect_payment).should == payment }
  end

  describe "POST create" do
    before{ post :create, ecconnect_payment: { amount: amount } }
    context "right data" do
      let(:amount){ 23 }
      it{ response.should redirect_to ecconnect_payment_path EcconnectPayment.last }
    end
    context "wrong data" do
      let(:amount){ nil }
      it{ response.should render_template('new') }
    end
  end

  describe "POST failure" do
    ['000', 101, 105, 108, 111, 116, 130, 290, 291, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411,
     412, 413, 420, 421, 430, 431, 432, 433, 434, 435, 436, 438, 439, 440, 441, 450, 501, 502, 503,
     504, 505, 506, 507, 508, 509, 510, 511, 601].each do |code|
      context "right signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
        before{ post :failure,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it{ response.should render_template 'failure' }
        it{ flash[:error].should == I18n.t("ecconnect_rails.codes.code_#{code}" ) }
      end 
      context "wrong signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
        before{ post :failure,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it{ response.should render_template 'failure' }
        it{ flash[:error].should == I18n.t("ecconnect_rails.wrong_signature") }
      end
      describe "override methods" do
        context "right signature" do
          before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
          it{ expect{ post :failure,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(3) }
        end
        context "wrong signature" do
          before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
          it{ expect{ post :failure,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(4) }
        end
      end
    end
  end

  describe "POST success" do
    ['000', 101, 105, 108, 111, 116, 130, 290, 291, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411,
     412, 413, 420, 421, 430, 431, 432, 433, 434, 435, 436, 438, 439, 440, 441, 450, 501, 502, 503,
     504, 505, 506, 507, 508, 509, 510, 511, 601].each do |code|
      context "right signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
        before{ post :success,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it do 
          if code == "000"
            response.should render_template 'success'
          else
            response.should render_template 'failure'
          end
        end
        it do 
          if code == "000"
            flash[:notice].should == I18n.t("ecconnect_rails.success")
          else
            flash[:error].should == I18n.t("ecconnect_rails.codes.code_#{code}" )
          end
        end
      end 
      context "wrong signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
        before{ post :success,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it{ response.should render_template 'failure' }
        it{ flash[:error].should == I18n.t("ecconnect_rails.wrong_signature") }
      end
      describe "override methods" do
        context "right signature" do
          if code == "000"
            before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
            it{ expect{ post :success,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(1) }
          else
            before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
            it{ expect{ post :success,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(3) }
          end
        end
        context "wrong signature" do
          before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
          it{ expect{ post :success,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(2) }
        end
      end
    end
  end

  describe "POST notify" do
    ['000', 101, 105, 108, 111, 116, 130, 290, 291, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411,
     412, 413, 420, 421, 430, 431, 432, 433, 434, 435, 436, 438, 439, 440, 441, 450, 501, 502, 503,
     504, 505, 506, 507, 508, 509, 510, 511, 601].each do |code|
      context "right signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
        before{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it do 
          if code == "000"
            response.should render_template 'notify'
            assigns(:action) == 'approve'
            assigns(:reason) == nil
            assigns(:forward_url) == nil
          else
            response.should render_template 'notify'
            assigns(:action) == 'reverse'
            assigns(:reason) == I18n.t("ecconnect_rails.codes.code_503")
            assigns(:forward_url) == nil
          end
        end
      end 
      context "wrong signature" do
        before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
        before{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
        it{ response.should render_template 'notify' }
        it{ assigns(:action) == 'reverse' }
        it{ assigns(:reason) == I18n.t("ecconnect_rails.codes.code_405") }
        it{ assigns(:forward_url) == nil }
      end
      describe "override methods" do
        context "right signature && right signature and code" do
          if code == "000" #right signature and code
            before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
            it{ expect{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(6) }
            context "override url" do
              before{ EcconnectPaymentsController.any_instance.stub(:forward_url_success).and_return('http://google.com') }
              before{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
              it{ assigns(:forward_url) == 'http://google.com' }
            end
          else #right signature
            before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(true) }
            it{ expect{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(5) }
            context "override url" do
              before{ EcconnectPaymentsController.any_instance.stub(:forward_url_failure).and_return('http://google.com.ua') }
              before{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
              it{ assigns(:forward_url) == 'http://google.com.ua' }
            end
          end
        end
        context "wrong signature" do
          before{ EcconnectPayment.any_instance.stub(:check_signature).and_return(false) }
          it{ expect{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }.to change{TestModel.count}.by(7) }
          context "override url" do
            before{ EcconnectPaymentsController.any_instance.stub(:forward_url_failure).and_return('http://google.com.ua') }
            before{ post :notify,  {'TranCode' => code.to_s, 'OrderID' => payment.order_id.to_s, 'Signature' => payment.income_signature} }
            it{ assigns(:forward_url) == 'http://google.com.ua' }
          end
        end
      end
    end
  end
end

