require 'spec_helper'
require 'capybara/session'
require 'mongoid'

feature "Sources" do
  let(:payment){ FactoryGirl.create :ecconnect_payment }
  let(:session){ Capybara::Session.new(:selenium) }

  subject { page }
  describe "payments" do
    context "payment new" do
      before do
        visit '/ecconnect_payments/new'
        fill_in('ecconnect_payment_amount', with: payment.amount)
        click_button('Create Ecconnect payment')
      end
      it{ find(:css, '#TotalAmount').value.should == payment.upc_amount.to_s }
    end
    context "payment show" do
      before{ visit "/ecconnect_payments/#{payment.to_param}" }
      it{ find(:css, '#TerminalID').value.should == payment.terminal_id.to_s }
      it{ find(:css, '#MerchantID').value.should == payment.merchant_id.to_s }
      it{ find(:css, '#Currency').value.should == payment.currency_id.to_s }
      it{ find(:css, '#TotalAmount').value.should == payment.upc_amount.to_s }
      it{ find(:css, '#locale').value.should == payment.locale.to_s }
      it{ find(:css, '#PurchaseTime').value.should == payment.purchase_time.to_s }
      it{ find(:css, '#OrderID').value.should == payment.order_id.to_s }
      it{ find(:css, '#Signature').value.should == payment.signature.to_s }
      it{ has_css?('#Delay').should be_false }
      it{ has_css?('#AltTotalAmount').should be_false }
      it{ has_css?('#AltCurrency').should be_false }
    end
    describe "selenium time" do
      let(:card){ nil }
      before(:all) do
        Mongoid.configure do |config|
          config.connect_to "dummy_development"
        end
      end
      after(:all) do
        Mongoid.configure do |config|
          config.connect_to "ecconnect_rails_test"
        end
      end
      before(:each) do
        session.visit("http://127.0.0.1:3000/ecconnect_payments/new")
        session.fill_in('ecconnect_payment_amount', with: payment.amount)
        session.click_button('Create Ecconnect payment')
        session.click_button(I18n.t('ecconnect_rails.ecconnect_form.submit'))        
        session.fill_in('CardNumber', with: card)
        session.select('12', :from => 'ExpMonth')
        session.select(Time.now.year.to_s, :from => 'ExpYear')
        session.fill_in('Email', with: 'test@upc.ua')
        session.click_button('>> Proceed')
        session.fill_in('Cvc', with: '999')
        session.click_button('>> Proceed')
      end
      after{ session.driver.browser.quit }
      describe "000" do
        let(:card){ 4999999999990011 }
        before{ session.driver.browser.switch_to.alert.accept; }
        it{ session.current_path.should == "/ecconnect_payments/success" }
      end
      describe "403" do
        let(:card){ 4999999999990102 }
        it{ session.current_url.should == EcconnectRails.default_options[:request_url] }
      end
    end
  end
end


