require 'spec_helper'

describe EcconnectPayment do
  let(:payment){ FactoryGirl.build :ecconnect_payment }

  #it{ should belong_to(:payer) }

  it{ should have_field(:delay).of_type(Boolean) }
  it{ should have_field(:merchant_id).of_type(Integer) }
  it{ should have_field(:created_at).of_type(Time) }
  it{ should have_field(:updated_at).of_type(Time) }
  it{ should have_field(:terminal_id).of_type(String) }
  it{ should have_field(:tran_code).of_type(String) }
  it{ should have_field(:approval_code).of_type(Integer) }
  it{ should have_field(:locale).of_type(String) }
  it{ should have_field(:proxy_pan).of_type(String) }
  it{ should have_field(:currency_id).of_type(Integer) }
  it{ should have_field(:alt_currency_id).of_type(Integer) }
  it{ should have_field(:amount).of_type(Float) }
  it{ should have_field(:alt_amount).of_type(Integer) }
  it{ should have_field(:order_id).of_type(Integer) }
  it{ should have_field(:email).of_type(String) }
  it{ should have_field(:income_signature).of_type(String) }
  it{ should have_field(:purchase_desc).of_type(String) }
  it{ should have_field(:sd).of_type(String) }
  it{ should have_field(:xid).of_type(String) }
  it{ should have_field(:rrn).of_type(String) }

  it{ should validate_presence_of(:merchant_id) }
  it{ should validate_presence_of(:terminal_id) }
  it{ should validate_presence_of(:currency_id) }
  it{ should validate_presence_of(:amount) }

  it{ payment.upc_amount.should == (FactoryGirl.attributes_for(:ecconnect_payment)[:amount]*100).to_i }
  it{ payment.signature.should == Base64.encode64(OpenSSL::PKey::RSA.new(File.read(Rails.root.join('certs/1753970.pem').to_s.gsub('dummy/', ''))).sign(OpenSSL::Digest::SHA1.new, (payment.request_data))).gsub(/\n/, '') }


  context "after_create" do
    let(:payment){ FactoryGirl.create :ecconnect_payment }
    it{ payment.merchant_id.should == MERCHANT_ID }
    it{ payment.terminal_id.should == TERMINAL_ID }
    it{ payment.currency_id == CURRENCY }
    it{ payment.currency.should == I18n.t("ecconnect_rails.currency_#{CURRENCY}") }
    it{ payment.locale == I18n.locale.to_s }
    it{ payment.purchase_time.should == payment.created_at.strftime("%Y%m%d%H%M%S%z") }
    context "tran code" do
      let(:payment){ FactoryGirl.create :ecconnect_payment_tran_code }
      it{ payment.tran_code == nil }
    end
  end
end